==> nextcloud-14.0.1.tgz: nextcloud/apps/sharebymail/l10n/fi.js <==
OC.L10N.register(
    "sharebymail",
    {
    "Shared with %1$s" : "Jaettu käyttäjälle %1$s",
    "Shared with {email}" : "Jaettu käyttäjälle {email}",
    "Shared with %1$s by %2$s" : "Jaettu käyttäjälle %1$s käyttäjältä %2$s",
    "Shared with {email} by {actor}" : "Jaettu käyttäjälle {email} käyttäjältä {actor}",
    "You shared %1$s with %2$s by mail" : "Jaoit tiedoston %1$s sähköpostitse osoitteeseen %2$s",
    "You shared {file} with {email} by mail" : "Jaoit tiedoston {file} sähköpostitse osoitteeseen {email}",
    "%3$s shared %1$s with %2$s by mail" : "%3$s jakoi tiedoston %1$s sähköpostitse osoitteeseen %2$s",
    "{actor} shared {file} with {email} by mail" : "{actor} jakoi tiedoston {file} sähköpostitse osoitteeseen {email}",
    "Password to access {file} was sent to you" : "Salasana tiedoston {file} käyttämiseksi lähetettiin sinulle",
    "Sharing %s failed, this item is already shared with %s" : "Kohteen %s jakaminen epäonnistui, koska se on jo jaettu käyttäjälle %s",
    "Failed to send share by email" : "Jaon lähettäminen sähköpostitse epäonnistui",
    "%s shared »%s« with you" : "%s jakoi kohteen »%s« kanssasi",
    "%s shared »%s« with you." : "%s jakoi kohteen »%s« kanssasi.",
    "Click the button below to open it." : "Klikkaa alla olevaa linkkiä avataksesi sen.",
    "Open »%s«" : "Avaa »%s«",
    "%s via %s" : "%s (palvelun %s kautta)",
    "It is protected with the following password: %s" : "Se on suojattu seuraavalla salasanalla: %s",
    "This is the password: %s" : "Tämä on salasana: %s",
    "You can choose a different password at any time in the share dialog." : "Voit valita muun salasanan koska tahansa jakovalikossa.",
    "Could not find share" : "Jakoa ei löytynyt",
    "Share by mail" : "Jaa sähköpostitse",
    "Allows users to share a personalized link to a file or folder by putting in an email address." : "Salli käyttäjien jakaa personoitu linkki tiedostoon tai kansioon syöttämällä sähköpostiosoitteen.",
    "Send password by mail" : "Lähetä salasana sähköpostitse",
    "Enforce password protection" : "Pakota salasanasuojaus",
    "Failed to send share by E-mail" : "Jaon lähettäminen sähköpostitse epäonnistui"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-21.0.4.tgz: nextcloud/apps/sharebymail/l10n/fi.js <==
OC.L10N.register(
    "sharebymail",
    {
    "Shared with %1$s" : "Jaettu käyttäjälle %1$s",
    "Shared with {email}" : "Jaettu käyttäjälle {email}",
    "Shared with %1$s by %2$s" : "Jaettu käyttäjälle %1$s käyttäjältä %2$s",
    "Shared with {email} by {actor}" : "Jaettu käyttäjälle {email} käyttäjältä {actor}",
    "You shared %1$s with %2$s by mail" : "Jaoit tiedoston %1$s sähköpostitse osoitteeseen %2$s",
    "You shared {file} with {email} by mail" : "Jaoit tiedoston {file} sähköpostitse osoitteeseen {email}",
    "%3$s shared %1$s with %2$s by mail" : "%3$s jakoi tiedoston %1$s sähköpostitse osoitteeseen %2$s",
    "{actor} shared {file} with {email} by mail" : "{actor} jakoi tiedoston {file} sähköpostitse osoitteeseen {email}",
    "Password to access {file} was sent to you" : "Salasana tiedoston {file} käyttämiseksi lähetettiin sinulle",
    "Failed to send share by email" : "Jaon lähettäminen sähköpostitse epäonnistui",
    "Click the button below to open it." : "Klikkaa alla olevaa linkkiä avataksesi sen.",
    "Open »%s«" : "Avaa »%s«",
    "It is protected with the following password:" : "Se on suojattu seuraavalla salasanalla:",
    "This is the password:" : "Tämä on salasana:",
    "You can choose a different password at any time in the share dialog." : "Voit valita muun salasanan koska tahansa jakovalikossa.",
    "Could not find share" : "Jakoa ei löytynyt",
    "Share by mail" : "Jaa sähköpostitse",
    "Allows users to share a personalized link to a file or folder by putting in an email address." : "Salli käyttäjien jakaa personoitu linkki tiedostoon tai kansioon syöttämällä sähköpostiosoitteen.",
    "Send password by mail" : "Lähetä salasana sähköpostitse",
    "Enforce password protection" : "Pakota salasanasuojaus",
    "Sharing %s failed, this item is already shared with %s" : "Kohteen %s jakaminen epäonnistui, koska se on jo jaettu käyttäjälle %s",
    "%s shared »%s« with you" : "%s jakoi kohteen »%s« kanssasi",
    "%s shared »%s« with you." : "%s jakoi kohteen »%s« kanssasi.",
    "%s via %s" : "%s (palvelun %s kautta)",
    "It is protected with the following password: %s" : "Se on suojattu seuraavalla salasanalla: %s",
    "This is the password: %s" : "Tämä on salasana: %s"
},
"nplurals=2; plural=(n != 1);");
